@@ -8,7 +8,7 @@ def roi_calc_mw(data_file, voi):
 
 	df = pd.read_csv(data_file)
 
-	trial_names = ['No Treatment', 'Cat Alone (1)', 'First Saline', 'Cat Alone (2)', 'First Urine', 'Cat Alone (3)', 'Second Saline', 'Cat Alone (4)', 'Second Urine', 'Cat Alone (5)']
+	trial_names = ['No treatment', 'Cat alone (1)', 'First saline', 'Cat alone (2)', 'First urine', 'Cat alone (3)', 'Second saline', 'Cat alone (4)', 'Second urine', 'Cat alone (5)']
 
 
 
